<?php

add_theme_support( 'menus' );
add_theme_support( 'post-thumbnails' );

function register_primary_menu() {
	register_nav_menu( 'primary', 'Main Navigation Menu' );
}
add_action( 'after_setup_theme', 'register_primary_menu' );

function add_additional_class_on_a($classes, $item, $args) {
	if (isset($args->add_a_class)) {
		$classes['class'] = $args->add_a_class;
	}
	return $classes;
}

add_filter('nav_menu_link_attributes', 'add_additional_class_on_a', 1, 3);

add_action( 'admin_menu', 'bb_logo_menu' );
 
function bb_logo_menu() {
	add_theme_page(
		'Logo Option',
		'Logo Option',
		'manage_options',
		'bb_logo',
		'bb_logo_page_callback',
		0 // menu position
	);
}
 
function bb_logo_page_callback() {
	?>
		<div class="wrap">
			<h1><?php echo get_admin_page_title() ?></h1>
			<p>Here you can select to display either the BB or BB/GA logo (the BB logo is displayed by default).</p>
			<form method="post" action="options.php">
				<?php
					settings_fields( 'bb_logo_settings' ); // settings group name
					do_settings_sections( 'bb_logo' ); // just a page slug
					submit_button(); // "Save Changes" button
				?>
			</form>
		</div>
	<?php
}

add_action( 'admin_init',  'bb_logo_settings_fields' );

function bb_logo_settings_fields() {

	// I created variables to make the things clearer
	$page_slug = 'bb_logo';
	$option_group = 'bb_logo_settings';

	// 1. create section
	add_settings_section(
		'bb_logo_section_id', // section ID
		'', // title (optional)
		'', // callback function to display the section (optional)
		$page_slug
	);

	// 2. register fields
	register_setting( $option_group, 'bbga_instead', 'bb_logo_sanitize_checkbox' );

	// 3. add fields
	add_settings_field(
		'bbga_instead',
		'Use BB/GA logo instead',
		'bb_logo_checkbox', // function to print the field
		$page_slug,
		'bb_logo_section_id' // section ID
	);
}

// custom callback function to print checkbox field HTML
function bb_logo_checkbox( $args ) {
	$value = get_option( 'bbga_instead' );
	?>
		<label>
			<input type="checkbox" name="bbga_instead" <?php checked( $value, 'yes' ) ?> /> Yes
		</label>
	<?php
}

// custom sanitization function for a checkbox field
function bb_logo_sanitize_checkbox( $value ) {
	return 'on' == $value ? 'yes' : 'no';
}

add_action( 'admin_notices', 'bb_logo_notice' );

function bb_logo_notice() {
	if(
		isset( $_GET[ 'page' ] ) 
		&& 'bb_logo' == $_GET[ 'page' ]
		&& isset( $_GET[ 'settings-updated' ] ) 
		&& true == $_GET[ 'settings-updated' ]
	) {
		?>
			<div class="notice notice-success is-dismissible">
				<p>
					<strong>Logo setting saved.</strong>
				</p>
			</div>
		<?php
	}
}

?>